diff src/eval.c @ 13945:6a653c300631

(syms_of_eval): Doc fix for inhibit-quit.
author Karl Heuer <kwzh@gnu.org>
date Thu, 04 Jan 1996 23:01:45 +0000
parents 353d32d374db
children 0df4b4f2a2a1
line wrap: on
line diff
--- a/src/eval.c	Thu Jan 04 22:59:53 1996 +0000
+++ b/src/eval.c	Thu Jan 04 23:01:45 1996 +0000
@@ -1208,8 +1208,8 @@
 #else
       if (EQ (clause, Qlambda))
 	{
-	  /* We can't return values to code which signalled an error, but we
-	     can continue code which has signalled a quit.  */
+	  /* We can't return values to code which signaled an error, but we
+	     can continue code which has signaled a quit.  */
 	  if (EQ (error_symbol, Qquit))
 	    return Qnil;
 	  else
@@ -2813,7 +2813,7 @@
   DEFVAR_LISP ("inhibit-quit", &Vinhibit_quit,
     "Non-nil inhibits C-g quitting from happening immediately.\n\
 Note that `quit-flag' will still be set by typing C-g,\n\
-so a quit will be signalled as soon as `inhibit-quit' is nil.\n\
+so a quit will be signaled as soon as `inhibit-quit' is nil.\n\
 To prevent this happening, set `quit-flag' to nil\n\
 before making `inhibit-quit' nil.");
   Vinhibit_quit = Qnil;